Function remoteit_api::auth::create_signature
source · pub fn create_signature(key: &[u8], message: &str) -> StringExpand description
You probably don’t want to use this function directly, unless you are implementing your own abstraction over the remote.it API.
Signs the given message with the given key with the HMAC algorithm and base64-encodes the result.
Returns
Base64 encoded HMAC signature.