Function remoteit_api::auth::get_date
source · pub fn get_date() -> StringExpand description
You probably don’t want to use this function directly, unless you are implementing your own abstraction for making requests to the remote.it API.
Creates a date string (now) to be used for signing requests to the remote.it API.
This function is used by [R3Client::send_remoteit_graphql_request] and [R3Client::send_remoteit_graphql_request_async].
Returns
A date string (now) in the format required by the remote.it API.