Module remoteit_api::file_upload
source · Expand description
Enabled by the file_upload feature. Contains structs and impl blocks related to uploading files to remote.it.
On the docs page of this module, you can only see the builder structs for the functions.
Please see [R3Client] for the actual functions you can call.
Structs
- The negative response from the remote.it API when uploading a file.
- Struct to hold the details of a file to be uploaded to remote.it.
- Use builder syntax to set the required parameters and finish by calling the method
Self::build(). - Use builder syntax to set the required parameters and finish by calling the method
Self::call(). - Use builder syntax to set the required parameters and finish by calling the method
Self::call(). - The positive response from the remote.it API when uploading a file.