Module remoteit_api::auth
source · Expand description
Contains functions related to request signing for the remote.it API. They are used by this lib, but you can also use them to implement your own abstraction.
Structs
- Use builder syntax to set the required parameters and finish by calling the method
Self::call().
Functions
- You probably don’t want to use this function directly, unless you are implementing your own abstraction over the remote.it API.
- You probably don’t want to use this function directly, unless you are implementing your own abstraction over the remote.it API.
- You probably don’t want to use this function directly, unless you are implementing your own abstraction for making requests to the remote.it API.